#include "hdf5.h"
#include "stdlib.h"

int
main (int argc, char **argv)
{

int mpi_rank, mpi_size;
int rank = 2;

hid_t file_id;        /* file identifier */
hid_t dset_id;        /* dataset identifiers */
hid_t filespace;      /* dataspace identifiers */
hid_t plist_id;       /* property list identifier */
hsize_t dimsf[rank];  /* dataset dimensions */

char H5FILE_NAME[128];   /* filename */

/* Initialize MPI */
MPI_Init(&argc, &argv);
MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);

/* setting filename */
sprintf(H5FILE_NAME,"%s.h5","RUN/my_second_parallel_file");
printf("I'm task %d of %d \n",mpi_rank,mpi_size);
if (mpi_rank==0) printf("creating h5 file %s...", H5FILE_NAME);

/* Set up file access property list for MPI-IO access */
plist_id = H5Pcreate(H5P_FILE_ACCESS);
H5Pset_fapl_mpio(plist_id, MPI_COMM_WORLD, MPI_INFO_NULL);

file_id = H5Fcreate(H5FILE_NAME, H5F_ACC_TRUNC, H5P_DEFAULT, plist_id);

/* Create the dataspace for the dataset.  */
dimsf[0] = 10;
dimsf[1] = 8;
filespace = H5Screate_simple(rank, dimsf, NULL);

/* Create the dataset with default properties collective. */
dset_id = H5Dcreate(file_id, "dataset1", H5T_NATIVE_INT, filespace, H5P_DEFAULT);
// 1.8 API
//dset_id = H5Dcreate(file_id, "dataset1", H5T_NATIVE_INT, filespace, H5P_DEFAULT,H5P_DEFAULT,H5P_DEFAULT);

/* close datest */
H5Dclose(dset_id);
H5Sclose(filespace);


/* release property list identifier */
H5Pclose(plist_id);

/* Close the file. */
H5Fclose(file_id);
if (mpi_rank==0) printf("...all done\n");
MPI_Finalize();

}


